==> ZenTaoPMS.17.2.php8.0.zip: zentaopms/extension/max/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPp4YGTZE2xeV8vRK+utB5TbhZHREQhQrs034R2GVUyrBIXbc95ulZB8OzF3/Ogn4mcVFZpuj
mij8uhfs80dVxJkKUU+oaSwhwLp1GKchft8vH548qpMM8YelUVQQhdW7U6j8io9wVn5wZoZbfFgP
cTTZ4rtlxSeiGmJsbQnYQO2YJp0z4iza/KuN9n2hfzrVFKgcgXhpdvCuyCVeWrph16LKPTYg0Dxf
m4OXw4sWij//wdfhlnFrysY+4ArjxcNoavsONYTCrQaIvWoKzcZX8ffIn3TVbPRpJdU2vw/EPdb+
8dfIxHtCZg8LTu8Q/Y+3XsS/RDWPj+PRKG8uN++MAROQC1hI2AafNgmiOQqx2jTq9UljuoK8N7d8
E3CX6iX9xhOds4hryJCoAvC518a6k/pDjRgp6FYAG5yRQX+iMvxD8r6qrZ7opZjpOpS+UxsHKMf+
DQCAd+TZZvBCyrh6893BpaG8uQob3WCZfPDV29wbtfVMhh06OvEy2hoRO4vMvOT1yLhlu1RV/fZ2
8GCscgwcTsd/822PMRTRxNAJC7oY0VJ91VjxEaTzSDzYmXcTq2cYhTQbG12hjiCWziAnd5g57nl/
ldJ7SH5AGMBCPBBniUmgsY2c5QBVrrwheeuGMzgK43k8BfXeWzCnDU5CLCJb0GkpLay4nYRL2KBJ
b0fnBWa+W7hTSUU1EpuGywzN1McuG/dHKtT71KHxvclq5weXeo5os1K=

==> ZenTaoPMS.17.4.php7.2_7.4.zip: zentaopms/extension/max/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPnf+8usynvUY3SgshW6ezuNP8v6ltmK3yipQmvHxCPfuC7XMuheJ9/w7IRlKmYAO+6O6Wrls
7XkJ+Mqs0AGVDSk0IAYuvM4z784Sn6Uo77riC8HkyV2S0+XvmEh+pZASb4KUNBwIf1ksTKRkSFWt
ni0iLg1fkrGx5RZ5pEADVV756vGXvP5naM7C5HxBXZISxdY5tyfqPwn2t2B/ZKWeVZLO8DTv1pMM
XjFpPtOTyyQTKxMcf3iZYUUmpnBvz3U2JpgRHPJT3/dbwPFiNmYCRHY0iopfOHxfof3dytrJqX2D
DPY2es2litqJj4zDZesb7YeK8Oxr1ygwkJWsqzkbAGd3ry3VGXH5+l/NlQufMmbENzgHlxmQxWLI
b9A3aCJ8EarYCOcC3423evUibZkNcCGHXHAn7Qo0FswRd5/5LZiFu93ZAT8JpLEH4s3u3iaDkvH9
HYz2L9QpmoB54dCwdQsxelvVKUZ/ZoSM1Kh2/DR3dWsMzO48WB/JPaEN3uWPpxWYsRpED00M4vb/
8o4zUYZmiwEyaiZbTJrO6GenhmIWbXubaQ38gEaPLDdHqcDOiaTm8VomFbA3ZYlXt1s9J2nTOMoH
y2CFQSgU+qYci91jtcicyN+Ex2v53n7IYIRTLucEP5kfQbjpmjc6bV3tsbSQx3I4OLIEJ9cChDS/
wJYx5pPpDA00c+dboxOgY3C+2tlbHWXEPw1t3T7avN82hCDlApy=
